@@ -23,16 +23,14 @@
 #include "settings_p.h"
 #include "spellerplugin_p.h"
 
-#include <QLocale>
 #include <QCache>
-#include <QSet>
 #include "core_debug.h"
 
 namespace Sonnet {
 class SpellerPrivate
 {
 public:
-    SpellerPrivate() : settings(nullptr)
+    SpellerPrivate()
     {
     }
 
@@ -271,10 +269,23 @@ QMap<QString, QString> Sonnet::Speller::availableDictionaries() const
     const QStringList lst = l->languages();
     QMap<QString, QString> langs;
 
-    Q_FOREACH (const QString &tag, lst) {
+    for (const QString &tag : lst) {
         langs.insert(l->languageNameForCode(tag), tag);
     }
 
     return langs;
 }
+
+QMap<QString, QString> Speller::preferredDictionaries() const
+{
+    Loader *l = Loader::openLoader();
+    QMap<QString, QString> langs;
+
+    for (const QString &tag : l->settings()->preferredLanguages()) {
+        langs.insert(l->languageNameForCode(tag), tag);
+    }
+
+    return langs;
 }
+
+} // namespace Sonnet
